package com.fs.hospital.mapper;



import com.fs.hospital.domain.HospitalUserRole;

import java.util.List;

/**
 * 用户和角色关联Mapper接口
 *
 * @author fs
 * @date 2021-05-25
 */
public interface HospitalUserRoleMapper
{
    /**
     * 查询用户和角色关联
     *
     * @param userId 用户和角色关联ID
     * @return 用户和角色关联
     */
    public HospitalUserRole selectHospitalUserRoleById(Long userId);

    /**
     * 查询用户和角色关联列表
     *
     * @param HospitalUserRole 用户和角色关联
     * @return 用户和角色关联集合
     */
    public List<HospitalUserRole> selectHospitalUserRoleList(HospitalUserRole HospitalUserRole);

    /**
     * 新增用户和角色关联
     *
     * @param HospitalUserRole 用户和角色关联
     * @return 结果
     */
    public int insertHospitalUserRole(HospitalUserRole HospitalUserRole);

    /**
     * 修改用户和角色关联
     *
     * @param HospitalUserRole 用户和角色关联
     * @return 结果
     */
    public int updateHospitalUserRole(HospitalUserRole HospitalUserRole);

    /**
     * 删除用户和角色关联
     *
     * @param userId 用户和角色关联ID
     * @return 结果
     */
    public int deleteHospitalUserRoleById(Long userId);

    /**
     * 批量删除用户和角色关联
     *
     * @param userIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteHospitalUserRoleByIds(Long[] userIds);

    int countUserRoleByRoleId(Long roleId);


    void batchUserRole(List<HospitalUserRole> list);

    void deleteUserRoleByUserId(Long userId);
}
